Learn R Programming

MorphSim (version 0.1.0)

get_lognormal_rates: Get discrete log-normal rates

Description

Computes a set of discrete log-normal rates for rate variation across sites or characters. The rates are normalized so that the mean rate equals 1.

Usage

get_lognormal_rates(meanlog, sdlog, k)

Value

Numeric vector of length k representing the discrete log-normal rates.

Arguments

meanlog

Numeric. Mean on the log scale.

sdlog

Numeric. Standard deviation on the log scale.

k

Integer. Number of rate categories.

Examples

Run this code
get_lognormal_rates(meanlog = 0, sdlog = 1, k = 4)

Run the code above in your browser using DataLab