powered by
Computes a set of discrete log-normal rates for rate variation across sites or characters. The rates are normalized so that the mean rate equals 1.
get_lognormal_rates(meanlog, sdlog, k)
Numeric vector of length k representing the discrete log-normal rates.
Numeric. Mean on the log scale.
Numeric. Standard deviation on the log scale.
Integer. Number of rate categories.
get_lognormal_rates(meanlog = 0, sdlog = 1, k = 4)
Run the code above in your browser using DataLab